@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -71,10 +71,12 @@ class AMQP(object):
         url_c = config.conf("RABBITMQ_URL", url_c)
         url = url or self.url or url_c or URL
         url_p = legacy.urlparse(url)
+        username = "guest" if url_p.username == None else url_p.username
+        password = "guest" if url_p.password == None else url_p.password
         parameters = _pika().ConnectionParameters(
             host = url_p.hostname,
             virtual_host = url_p.path or "/",
-            credentials = _pika().PlainCredentials(url_p.username, url_p.password)
+            credentials = _pika().PlainCredentials(username, password)
         )
         parameters.socket_timeout = timeout
         self._connection = _pika().BlockingConnection(parameters)
