@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -327,7 +327,7 @@ class API(observer.Observable):
 
 class OAuthAPI(API):
     """
-    Abstract class for the implementation of oauth based
+    Abstract class for the implementation of OAuth based
     infra-structure, should expose a series of utilities
     for the authentication using oauth.
 
@@ -341,7 +341,7 @@ class OAuthAPI(API):
     it and ensuring a complete authentication """
 
     OAUTH_MODE = 2
-    """ The oauth client mode where the set of permissions
+    """ The OAuth client mode where the set of permissions
     (scope) is authorized on behalf on an already authenticated
     user using a web agent (recommended mode) """
 
