@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -201,16 +201,25 @@ class MemoryHandler(logging.Handler):
         slice = itertools.islice(messages, 0, count)
         return list(slice)
 
-    def flush_to_file(self, path, count = None, level = None, clear = True):
+    def flush_to_file(
+        self,
+        path,
+        count = None,
+        level = None,
+        reverse = True,
+        clear = True
+    ):
         messages = self.get_latest(level = level, count = count or 65536)
         if not messages: return
-        file = open(path, "wb")
+        if reverse: messages.reverse()
+        is_path = isinstance(path, legacy.STRINGS)
+        file = open(path, "wb") if is_path else path
         try:
             for message in messages:
                 message = legacy.bytes(message, "utf-8", force = True)
                 file.write(message + b"\n")
         finally:
-            file.close()
+            if is_path: file.close()
         if clear: self.clear()
 
 class BaseFormatter(logging.Formatter):
