@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -159,6 +159,8 @@ class Request(object):
         self.prefixes = None
         self.session = session.MockSession(self)
         self.set_cookie = None
+        self.set_cookie_prefix = None
+        self.set_cookie_suffix = None
         self.post = {}
         self.files = {}
         self.args = {}
@@ -216,6 +218,8 @@ class Request(object):
         self.prefixes = None
         self.session = None
         self.set_cookie = None
+        self.set_cookie_prefix = None
+        self.set_cookie_suffix = None
         self.post = None
         self.files = None
         self.args = None
@@ -708,7 +712,7 @@ class Request(object):
         sid = str(sid) if type(sid) == legacy.UNICODE else sid
 
         # tries to retrieve the session reference for the
-        # provided sid (session id) in case there's an exception
+        # provided SID (session id) in case there's an exception
         # defaults to unset session so that a new one gets created
         try: session = self.session_c.get_s(sid, request = self)
         except Exception: session = None
@@ -723,6 +727,17 @@ class Request(object):
     def get_session(self):
         return self.session
 
+    def get_session_agent(self):
+        if not self.session: return None
+        if not self.session.is_loaded(): return None
+        username = self.session.get("username", None)
+        if username: return username
+        email = self.session.get("email", None)
+        if email: return email
+        id = self.session.get("id", None)
+        if id: return id
+        return None
+
     def get_warnings(self):
         return self.warnings
 
@@ -732,7 +747,14 @@ class Request(object):
         expires = time.time() + delta
         expires_d = datetime.datetime.fromtimestamp(expires)
         with util.ctx_locale(): expires_s = expires_d.strftime("%a, %m %b %Y %H:%M:%S GMT")
-        set_cookie = "%s;lang=%s;path=%s;expires=%s;" % (base, lang, path, expires_s)
+        set_cookie = "%s%s;lang=%s;path=%s;expires=%s;%s" % (
+            self.set_cookie_prefix or self.owner.set_cookie_prefix or "",
+            base,
+            lang,
+            path,
+            expires_s,
+            self.set_cookie_suffix or self.owner.set_cookie_suffix or "",
+        )
         return set_cookie
 
     def get_headers(self):
