@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -126,6 +126,39 @@ class ModelTest(unittest.TestCase):
         result = mock.Person.count()
         self.assertEqual(result, 0)
 
+    def test_advance(self):
+        result = mock.Person.count()
+        self.assertEqual(result, 0)
+
+        person = mock.Person()
+        person.age = 1
+        person.name = "Name"
+        person.save()
+
+        result = mock.Person.count()
+        self.assertEqual(result, 1)
+
+        result = person.advance("age")
+        self.assertEqual(result, 2)
+        self.assertEqual(person.age, 2)
+
+        person = person.reload()
+        self.assertEqual(person.age, 2)
+
+        result = person.advance("age", delta = 2)
+        self.assertEqual(result, 4)
+        self.assertEqual(person.age, 4)
+
+        person = person.reload()
+        self.assertEqual(person.age, 4)
+
+        result = person.advance("age", delta = -2)
+        self.assertEqual(result, 2)
+        self.assertEqual(person.age, 2)
+
+        person = person.reload()
+        self.assertEqual(person.age, 2)
+
     def test_validation(self):
         person = mock.Person()
 
@@ -335,6 +368,13 @@ class ModelTest(unittest.TestCase):
         cat.name = "NameCat"
         cat.save()
 
+        cat_friend = mock.Cat()
+        cat_friend.name = "NameCatFriend"
+        cat_friend.save()
+
+        cat.friend = cat_friend
+        cat.save()
+
         person.cats = [cat]
         person.save()
 
@@ -360,7 +400,12 @@ class ModelTest(unittest.TestCase):
 
         person = mock.Person.get(identifier = 1, eager = ("cats",))
 
+        self.assertEqual(isinstance(person.cats, appier.References), True)
+        self.assertEqual(isinstance(person.cats[0].friend, appier.Reference), True)
         self.assertEqual(person.cats.is_resolved(), True)
+        self.assertEqual(person.cats[0].friend.is_resolved(), False)
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(person.cats[0].name, "NameCat")
 
         person = mock.Person.get(
             identifier = 1,
@@ -371,6 +416,36 @@ class ModelTest(unittest.TestCase):
         self.assertEqual(isinstance(person, dict), True)
         self.assertEqual(isinstance(person["cats"], list), True)
         self.assertEqual(isinstance(person["cats"][0], dict), True)
+        self.assertEqual(isinstance(person["cats"], appier.References), False)
+        self.assertEqual(isinstance(person["cats"][0]["friend"], appier.Reference), False)
+        self.assertEqual(len(person["cats"]), 1)
+        self.assertEqual(person["cats"][0]["name"], "NameCat")
+        self.assertEqual(person["cats"][0]["friend"], 2)
+
+        person = mock.Person.get(identifier = 1, eager = ("cats.friend",))
+
+        self.assertEqual(isinstance(person.cats, appier.References), True)
+        self.assertEqual(isinstance(person.cats[0].friend, appier.Reference), True)
+        self.assertEqual(person.cats.is_resolved(), True)
+        self.assertEqual(person.cats[0].friend.is_resolved(), True)
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(person.cats[0].name, "NameCat")
+        self.assertEqual(person.cats[0].friend.name, "NameCatFriend")
+
+        person = mock.Person.get(
+            identifier = 1,
+            map = True,
+            eager = ("cats.friend",)
+        )
+
+        self.assertEqual(isinstance(person, dict), True)
+        self.assertEqual(isinstance(person["cats"], list), True)
+        self.assertEqual(isinstance(person["cats"][0], dict), True)
+        self.assertEqual(isinstance(person["cats"][0]["friend"], dict), True)
+        self.assertEqual(isinstance(person["cats"], appier.References), False)
+        self.assertEqual(isinstance(person["cats"][0]["friend"], appier.Reference), False)
+        self.assertEqual(person["cats"][0]["name"], "NameCat")
+        self.assertEqual(person["cats"][0]["friend"]["name"], "NameCatFriend")
 
         person = mock.Person.get(identifier = 1)
 
@@ -628,3 +703,139 @@ class ModelTest(unittest.TestCase):
         self.assertEqual(person.father.is_resolved(), False)
         self.assertEqual(appier.is_unset(person.car), True)
         self.assertEqual(person.car, None)
+
+    def test_map_v(self):
+        person = mock.Person()
+        person.name = "Name"
+
+        cat = mock.Cat()
+        cat.name = "NameCat"
+        cat.save()
+
+        cat_friend = mock.Cat()
+        cat_friend.name = "NameCatFriend"
+        cat_friend.save()
+
+        cat.friend = cat_friend
+        cat.save()
+
+        person.cats = [cat]
+        person.save()
+
+        person = mock.Person.get(identifier = 1)
+        person_m = person.map_v()
+
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(isinstance(person.cats[0], dict), True)
+        self.assertEqual(person.cats[0]["friend"]["name"], "NameCatFriend")
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], dict), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"]["name"], "NameCatFriend")
+
+        person = person.reload()
+        person_m = person.map_v(resolve = False)
+
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(isinstance(person.cats[0], int), 1)
+        self.assertEqual(person.cats[0], 1)
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], int), True)
+        self.assertEqual(person_m["cats"][0], 1)
+
+        person = mock.Person.get(identifier = 1, eager = ("cats",))
+        person_m = person.map_v(resolve = False)
+
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(isinstance(person.cats[0], dict), True)
+        self.assertEqual(person.cats[0]["friend"], 2)
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], int), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"], 2)
+
+        person = mock.Person.get(identifier = 1, eager = ("cats",))
+        person_m = person.map_v(resolve = False, evaluator = "map_v")
+
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(isinstance(person.cats[0], dict), True)
+        self.assertEqual(person.cats[0]["friend"], 2)
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], int), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"], 2)
+
+        person = mock.Person.get(identifier = 1, eager = ("cats",))
+        person_m = person.map_v(clone = True, resolve = False)
+
+        self.assertEqual(isinstance(person.cats, appier.References), True)
+        self.assertEqual(person.cats.is_resolved(), True)
+        self.assertEqual(isinstance(person.cats[0].friend, appier.Reference), True)
+        self.assertEqual(person.cats[0].friend.is_resolved(), False)
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], int), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"], 2)
+
+        person = mock.Person.get(identifier = 1, eager = ("cats.friend",))
+        person_m = person.map_v(resolve = False)
+
+        self.assertEqual(len(person.cats), 1)
+        self.assertEqual(isinstance(person.cats[0], dict), True)
+        self.assertEqual(person.cats[0]["friend"]["name"], "NameCatFriend")
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], dict), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"]["name"], "NameCatFriend")
+
+        person = mock.Person.get(identifier = 1, eager = ("cats.friend",))
+        person_m = person.map_v(clone = True, resolve = False)
+
+        self.assertEqual(isinstance(person.cats, appier.References), True)
+        self.assertEqual(person.cats.is_resolved(), True)
+        self.assertEqual(isinstance(person.cats[0].friend, appier.Reference), True)
+        self.assertEqual(person.cats[0].friend.is_resolved(), True)
+        self.assertEqual(len(person_m["cats"]), 1)
+        self.assertEqual(isinstance(person_m["cats"][0], dict), True)
+        self.assertEqual(isinstance(person_m["cats"][0]["friend"], dict), True)
+        self.assertEqual(person_m["cats"][0]["name"], "NameCat")
+        self.assertEqual(person_m["cats"][0]["friend"]["name"], "NameCatFriend")
+
+    def test_clone(self):
+        person = mock.Person()
+        person.name = "Name"
+
+        person.save()
+
+        self.assertEqual(person.identifier, 1)
+        self.assertEqual(person.name, "Name")
+
+        person_c = person.clone()
+        person_c.name = "NameC"
+        person_c.save()
+
+        self.assertEqual(id(person_c.model), id(person.model))
+        self.assertEqual(person_c.model, person.model)
+        self.assertEqual(person_c.identifier, 2)
+        self.assertEqual(person_c.name, "NameC")
+
+        person_c = person.clone(reset = False)
+
+        self.assertEqual(id(person_c.model), id(person.model))
+        self.assertEqual(person_c.model, person.model)
+        self.assertEqual(person_c.identifier, 2)
+        self.assertEqual(person_c.name, "NameC")
+
+        person_c = person.clone(deep = True)
+        person_c.name = "NameC2"
+        person_c.save()
+
+        self.assertNotEqual(id(person_c.model), id(person.model))
+        self.assertNotEqual(person_c.model, person.model)
+        self.assertEqual(person_c.identifier, 3)
+        self.assertEqual(person_c.name, "NameC2")
