@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -688,6 +688,9 @@ class UtilTest(unittest.TestCase):
         result = appier.escape("foo$,bar", ",", escape = "$")
         self.assertEqual(result, "foo$$$,bar")
 
+        result = appier.escape("foo$,bar:", (",", ":"), escape = "$")
+        self.assertEqual(result, "foo$$$,bar$:")
+
     def test_unescape(self):
         result = appier.unescape("foo$,bar", escape = "$")
         self.assertEqual(result, "foo,bar")
@@ -695,6 +698,9 @@ class UtilTest(unittest.TestCase):
         result = appier.unescape("foo$$,bar", escape = "$")
         self.assertEqual(result, "foo$,bar")
 
+        result = appier.unescape("foo$$,bar$:", escape = "$")
+        self.assertEqual(result, "foo$,bar:")
+
         result = appier.unescape("$$foo$,bar$$$$", escape = "$")
         self.assertEqual(result, "$foo,bar$$")
 
@@ -995,6 +1001,69 @@ class UtilTest(unittest.TestCase):
             )
         ))
 
+        result = appier.dict_merge(first, second, override = False, recursive = True)
+        self.assertEqual(id(result) in (id(first), (id(second))), False)
+        self.assertEqual(result["a"], dict(
+            a = "hello",
+            b = "world",
+            c = "other",
+            d = "other",
+            m = dict(
+                a = "hello",
+                b = "world"
+            )
+        ))
+
+        first = {
+            "info" : {
+                "personal" : {
+                    "general" : {
+                        "kind" : "human",
+                    }
+                }
+            }
+        }
+        second = {
+            "info" : {
+                "personal" : {
+                    "general": {
+                        "kind" : "cat",
+                        "tail" : "long",
+                        "meaw" : 12
+                    }
+                },
+                "profile": "base"
+            }
+        }
+
+        result = appier.dict_merge(first, second, override = False, recursive = True)
+        self.assertEqual(id(result) in (id(first), (id(second))), False)
+        self.assertEqual(result, {
+            "info" : {
+                "personal" : {
+                    "general" : {
+                        "kind" : "human",
+                        "tail" : "long",
+                        "meaw" : 12
+                    }
+                },
+                "profile": "base"
+            }
+        })
+
+        result = appier.dict_merge(first["info"], second["info"], override = False, recursive = True)
+        self.assertEqual(id(result) in (id(first), (id(second))), False)
+        self.assertEqual(result, {
+            "personal": {
+                "general": {
+                    "kind" : "human",
+                    "tail" : "long",
+                    "meaw" : 12
+                }
+            },
+            "profile": "base"
+        })
+
     def test_verify(self):
         result = appier.verify(1 == 1)
         self.assertEqual(result, None)
@@ -1037,6 +1106,30 @@ class UtilTest(unittest.TestCase):
             lambda: appier.verify_not_equal(1, 1, exception = appier.OperationalError)
         )
 
+    def test_verify_type(self):
+        result = appier.verify_type("hello", str)
+        self.assertEqual(result, None)
+
+        result = appier.verify_type(1, int)
+        self.assertEqual(result, None)
+
+        result = appier.verify_type(None, int)
+        self.assertEqual(result, None)
+
+        self.assertRaises(appier.AssertionError, lambda: appier.verify_type(1, str))
+
+        self.assertRaises(
+            appier.OperationalError,
+            lambda: appier.verify_type(1, str, exception = appier.OperationalError)
+        )
+
+        self.assertRaises(appier.AssertionError, lambda: appier.verify_type(None, str, null = False))
+
+        self.assertRaises(
+            appier.OperationalError,
+            lambda: appier.verify_type(None, str, null = False, exception = appier.OperationalError)
+        )
+
     def test_verify_many(self):
         result = appier.verify_many((1 == 1, 2 == 2, 3 == 3))
         self.assertEqual(result, None)
